@@ -77,7 +77,7 @@ umxGxEbiv <- function(name = "GxEbiv", selDVs, selDefs, dzData, mzData, sep = NU
 			stop("sep should be just one word, like '_T'. I will add 1 and 2 afterwards... \n", 
 				"i.e., you have to name your variables 'obese_T1' and 'obese_T2' etc.")
 		}
-		selDVs = umx_paste_names(selDVs, sep, 1:nSib)
+		selDVs  = umx_paste_names(selDVs, sep, 1:nSib)
 		selDefs = umx_paste_names(selDefs, sep, 1:nSib)
 	}
 	if(any(selDefs %in% selDVs)){
@@ -91,8 +91,9 @@ umxGxEbiv <- function(name = "GxEbiv", selDVs, selDefs, dzData, mzData, sep = NU
 		umx_msg(selDefs)
 		warning("selDefs must be length = 2. Or perhaps you didn't set sep = ?")
 	}
-	umx_check_names(selDVs, mzData)
+	umx_check_names(selDefs, mzData)
 	umx_check_names(selDVs, dzData)
+
 	message("selDVs: ", omxQuotes(selDVs))
 	umx_check(!umx_is_cov(dzData, boolean = TRUE), "stop", "Data must be raw for umxGxEbiv")
 	# TODO umxGxEbiv Check Defs are not correlated 1 or 0
